@@ -1,7 +1,8 @@
-from pyaliner.align import align, LEV, COMPACT, CLASSIC, GAP, JOIN, Seq, as_cigar, compact
+from pyaliner.align import align, LEV, COMPACT, CLASSIC, GAP, JOIN, SKIP, Seq, as_cigar, compact, itp_align, tp1p2_align
 from pyaliner.compare import compare_in_true_pred_from_file, compare_true_pred_from_file, compare_in_true_pred, \
     compare_true_pred, compare_in_true_pred_from_files, compare_true_pred_from_files
-from pyaliner.display import in_terminal, rich_paired_in_true_pred, rich_paired_true_pred, rich_inlined_true_pred
+from pyaliner.display import in_terminal, rich_paired_in_true_pred, rich_paired_true_pred, rich_inlined_true_pred, \
+    seq_true_pred_paired, seq_in_true_pred_paired
 
 __all__ = ['align',
            'LEV',
@@ -9,9 +10,12 @@ __all__ = ['align',
            'CLASSIC',
            'GAP',
            'JOIN',
+           'SKIP',
            'Seq',
            'as_cigar',
            'compact',
+           'itp_align',
+           'tp1p2_align',
            'compare_in_true_pred_from_file',
            'compare_in_true_pred_from_files',
            'compare_true_pred_from_file',
@@ -21,4 +25,6 @@ __all__ = ['align',
            'in_terminal',
            'rich_paired_in_true_pred',
            'rich_paired_true_pred',
-           'rich_inlined_true_pred']
+           'rich_inlined_true_pred',
+           'seq_true_pred_paired',
+           'seq_in_true_pred_paired']
